"""Sphinx configuration for conda-express documentation."""

import os
import sys

sys.path.insert(0, os.path.abspath(".."))

project = html_title = "conda-express"
copyright = "2026, conda community"
author = "conda community"

extensions = [
    "myst_parser",
    "sphinx_copybutton",
    "sphinx_design",
    "sphinx_reredirects",
    "sphinx_sitemap",
]

myst_enable_extensions = [
    "colon_fence",
    "deflist",
    "fieldlist",
    "tasklist",
]

html_theme = "conda_sphinx_theme"

html_theme_options = {
    "icon_links": [
        {
            "name": "GitHub",
            "url": "https://github.com/jezdez/conda-express",
            "icon": "fa-brands fa-square-github",
            "type": "fontawesome",
        },
        {
            "name": "PyPI",
            "url": "https://pypi.org/project/conda-express/",
            "icon": "fa-brands fa-python",
            "type": "fontawesome",
        },
    ],
}

html_context = {
    "github_user": "jezdez",
    "github_repo": "conda-express",
    "github_version": "main",
    "doc_path": "docs",
}

html_static_path = ["_static"]
html_extra_path = ["../scripts/get-cx.sh", "../scripts/get-cx.ps1"]
html_css_files = ["css/custom.css"]

html_baseurl = "https://jezdez.github.io/conda-express/"

exclude_patterns = ["_build"]



from __future__ import annotations

import os
import subprocess
import sys

from conda_express import find_cx_bin


def main() -> None:
    cx = find_cx_bin()

    args = [cx, *sys.argv[1:]]
    if sys.platform == "win32":
        raise SystemExit(subprocess.call(args))
    else:
        os.execvp(cx, args)


if __name__ == "__main__":
    main()
